package com.lnb.multidatasourcedemo.listener;

import com.lnb.multidatasourcedemo.curator.CuratorClient;
import com.lnb.multidatasourcedemo.datasource.DynamicDataSource;
import lombok.extern.slf4j.Slf4j;
import org.apache.curator.framework.CuratorFramework;
import org.apache.curator.framework.recipes.cache.PathChildrenCacheEvent;
import org.apache.curator.framework.recipes.cache.PathChildrenCacheListener;

/**
 * 路由监听
 * Created by liaoningbo on 2021/11/24
 */
@Slf4j
public class AppListener implements PathChildrenCacheListener {

    private DynamicDataSource dynamicDataSource;

    private CuratorClient curatorClient;

    public AppListener(DynamicDataSource dynamicDataSource, CuratorClient curatorClient) {
        this.dynamicDataSource = dynamicDataSource;
        this.curatorClient = curatorClient;
    }

    @Override
    public void childEvent(CuratorFramework client, PathChildrenCacheEvent event) throws Exception {
        log.info("AppListener event type : [" + event.getType() + "] ");
        switch (event.getType()) {
            case CHILD_ADDED:
            case CHILD_UPDATED:
                registerApp(event);
                break;
            case CHILD_REMOVED:
                break;
            default:
                break;
        }
    }

    private void registerApp(PathChildrenCacheEvent event) throws Exception {
        String app = getApp(event.getData().getPath());
        //添加节点时内容可能为空，这时注册节点下路径监听器
        if (PathChildrenCacheEvent.Type.CHILD_ADDED.equals(event.getType()))
            curatorClient.registerDbconfigListenter(dynamicDataSource, app);
    }

    private String getApp(String path) {
        return path.substring(path.lastIndexOf("/") + 1, path.length());
    }

}
