package com.lnb.multidatasourcedemo.listener;

import com.lnb.multidatasourcedemo.curator.CuratorClient;
import com.lnb.multidatasourcedemo.curator.ZkProperties;
import com.lnb.multidatasourcedemo.datasource.DynamicDataSource;
import com.lnb.multidatasourcedemo.utils.CommonUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.curator.framework.CuratorFramework;
import org.apache.curator.framework.state.ConnectionState;
import org.apache.curator.framework.state.ConnectionStateListener;

/**
 * zk链接监听
 * Created by liaoningbo on 2021/11/24
 */
@Slf4j
public class ZKConnectionStateListener implements ConnectionStateListener {

    private DynamicDataSource dynamicDataSource;

    private CuratorClient curatorClient;

    private ZkProperties zkProperties;

    public ZKConnectionStateListener(DynamicDataSource dynamicDataSource, CuratorClient curatorClient, ZkProperties zkProperties) {
        this.dynamicDataSource = dynamicDataSource;
        this.curatorClient = curatorClient;
        this.zkProperties = zkProperties;
    }

    @Override
    public void stateChanged(CuratorFramework curatorFramework, ConnectionState connectionState) {
        log.info("ZKConnectionStateListener connectionState : [" + connectionState + "] ");
        if (connectionState == ConnectionState.LOST || connectionState == ConnectionState.SUSPENDED) {
            //连接丢失,报警
            log.warn("Lost session with zookeeper at[" + CommonUtils.getDateByDefault() + "].");
        } else if (connectionState == ConnectionState.CONNECTED) {
            //连接新建
            log.info("Connected with zookeeper");
        } else if (connectionState == ConnectionState.RECONNECTED) {
            log.info("Reconnected with zookeeper， don't care.");
        }
    }
}
